@@ -93,22 +93,25 @@ static void benchmarkHashFunctionTime (char * name)
 			int32_t seed;
 			if (getRandomSeed (&seed) != &seed) printExit ("Seed Parsing Error or feed me more seeds");
 			KeySet * ks = generateKeySet (n[i], &seed, &keySetShapes[s]);
+			ssize_t ksSize = ksGetSize (ks);
 			for (size_t r = 0; r < runs; ++r)
 			{
 				Key * key;
-				ksRewind (ks);
+
 				struct timeval start;
 				struct timeval end;
 				__asm__("");
 				gettimeofday (&start, 0);
 				__asm__("");
 				// measure
-				while ((key = ksNext (ks)))
+				for (elektraCursor it = 0; it < ksSize; ++it)
 				{
+					key = ksAtCursor (ks, it);
 					__asm__("");
 					opmphmHashfunction (keyName (key), strlen (keyName (key)), 1337);
 					__asm__("");
 				}
+
 				__asm__("");
 				gettimeofday (&end, 0);
 				__asm__("");
@@ -1246,7 +1249,7 @@ void benchmarkOPMPHMBuildTime (char * name)
  *
  * @retval median time
  */
-static size_t benchmarkSearchTimeMeasure (KeySet * ks, size_t searches, int32_t searchSeed, option_t option, size_t * repeats,
+static size_t benchmarkSearchTimeMeasure (KeySet * ks, size_t searches, int32_t searchSeed, elektraLookupFlags option, size_t * repeats,
 					  size_t numberOfRepeats)
 {
 	if (option & KDB_O_OPMPHM)
@@ -1337,7 +1340,7 @@ static size_t benchmarkSearchTimeMeasure (KeySet * ks, size_t searches, int32_t
  * @param outFileName the output file name
  * @param option the option to pass to the ksLookup (...)
  */
-static void benchmarkSearchTime (char * name, char * outFileName, option_t option)
+static void benchmarkSearchTime (char * name, char * outFileName, elektraLookupFlags option)
 {
 	const size_t startN = 50;
 	const size_t stepN = 500;
@@ -1566,7 +1569,10 @@ static size_t benchmarkHsearchBuildTimeMeasure (KeySet * ks, size_t nI, double l
 		struct timeval start;
 		struct timeval end;
 		Key * key;
-		ksRewind (ks);
+
+		elektraCursor it;
+		ssize_t ksSize = ksGetSize (ks);
+
 		ENTRY e;
 		ENTRY * ep;
 		// fresh htab
@@ -1586,8 +1592,10 @@ static size_t benchmarkHsearchBuildTimeMeasure (KeySet * ks, size_t nI, double l
 			printExit ("hcreate_r");
 		}
 
-		while ((key = ksNext (ks)))
+		for (it = 0; it < ksSize; ++it)
 		{
+			key = ksAtCursor (ks, it);
+
 			e.key = (char *) keyName (key);
 			e.data = key;
 			if (!hsearch_r (e, ENTER, &ep, htab))
@@ -1605,9 +1613,9 @@ static size_t benchmarkHsearchBuildTimeMeasure (KeySet * ks, size_t nI, double l
 		repeats[repeatsI] = (end.tv_sec - start.tv_sec) * 1000000 + (end.tv_usec - start.tv_usec);
 
 		// sanity check
-		ksRewind (ks);
-		while ((key = ksNext (ks)))
+		for (it = 0; it < ksSize; ++it)
 		{
+			key = ksAtCursor (ks, it);
 			e.key = (char *) keyName (key);
 			if (!hsearch_r (e, FIND, &ep, htab))
 			{
@@ -2083,11 +2091,15 @@ static void benchmarkPrintAllKeySetShapes (char * name)
 		{
 			printf (" ======================= shapeId %zu =======================\n\n", shapeId);
 			Key * key;
-			ksRewind (ks);
-			while ((key = ksNext (ks)))
+			elektraCursor it;
+			ssize_t ksSize = ksGetSize (ks);
+
+			for (it = 0; it < ksSize; ++it)
 			{
+				key = ksAtCursor (ks, it);
 				printf ("%s\n", keyName (key));
 			}
+
 			printf ("\n ======================== size %zd ========================\n\n", ksGetSize (ks));
 		}
 		ksDel (ks);
@@ -2461,7 +2473,7 @@ static void shapefCommonStartEnd (const size_t initSize ELEKTRA_UNUSED, size_t s
 	}
 }
 /**
- * modules, level 1 keys same, one level 2 key stores the modules. Like system/elektra.
+ * modules, level 1 keys same, one level 2 key stores the modules. Like system:/elektra.
  */
 static void * shapeModulesInit (void)
 {
@@ -2496,13 +2508,13 @@ static void shapefModules (const size_t initSize, size_t size ELEKTRA_UNUSED, si
 	uint8_t * assign = &d[3];
 	if (level == 1)
 	{
-		// common start, simulates elektra in system/elektra
+		// common start, simulates elektra in system:/elektra
 		ret->subKeys = 1;
 		ret->label = 0;
 	}
 	else if (level == 2)
 	{
-		// common name, simulates modules in system/elektra/modules
+		// common name, simulates modules in system:/elektra/modules
 		// calculates how many modules have space
 		ret->subKeys = 0;
 		ssize_t remainingSize = initSize;
