@@ -12,10 +12,10 @@
 kdb::KeySet ksDeepCopy (kdb::KeySet orig)
 {
 	kdb::KeySet deepCopy;
-	orig.rewind ();
-	while (orig.next ())
+
+	for (ssize_t it = 0; it < orig.size (); ++it)
 	{
-		deepCopy.append (orig.current ().dup ());
+		deepCopy.append (orig.at (it).dup ());
 	}
 	return deepCopy;
 }
@@ -23,8 +23,8 @@ kdb::KeySet ksDeepCopy (kdb::KeySet orig)
 
 int main ()
 {
-	kdb::KeySet orig (3, *kdb::Key ("user/key3/1", KEY_END), *kdb::Key ("user/key3/2", KEY_END),
-			  *kdb::Key ("user/key3/3", KEY_VALUE, "value", KEY_END), KS_END);
+	kdb::KeySet orig (3, *kdb::Key ("user:/key3/1", KEY_END), *kdb::Key ("user:/key3/2", KEY_END),
+			  *kdb::Key ("user:/key3/3", KEY_VALUE, "value", KEY_END), KS_END);
 	kdb::KeySet flatCopy (orig);
 	kdb::KeySet deepCopy = ksDeepCopy (orig);
 }
