@@ -241,10 +241,10 @@ static int prependStringToAllKeyNames (KeySet * result, KeySet * input, const ch
 		ELEKTRA_SET_INTERNAL_ERROR (informationKey, "Parameter string must not be null.");
 		return -1;
 	}
-	Key * key;
-	ksRewind (input);
-	while ((key = ksNext (input)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (input); ++it)
 	{
+		const Key * key = ksAtCursor (input, it);
 		bool isRoot = strcmp (keyName (key), "/root") == 0;
 		size_t size = strlen (string);
 		if (isRoot)
@@ -289,12 +289,12 @@ static int prependStringToAllKeyNames (KeySet * result, KeySet * input, const ch
  */
 static KeySet * removeRoot (KeySet * original, Key * root, Key * informationKey)
 {
-	ksRewind (original);
 	KeySet * result = ksNew (0, KS_END);
 	const char * rootKeyNameString = keyName (root);
-	Key * currentKey;
-	while ((currentKey = ksNext (original)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (original); ++it)
 	{
+		const Key * currentKey = ksAtCursor (original, it);
 		char * currentKeyNameString = elektraMalloc (keyGetNameSize (currentKey));
 		if (keyGetName (currentKey, currentKeyNameString, keyGetNameSize (currentKey)) < 0)
 		{
@@ -612,12 +612,9 @@ static int allExistHelper (Key * checkedKey, Key * keyInFirst, Key * keyInSecond
 static int checkSingleSet (KeySet * checkedSet, KeySet * firstCompared, KeySet * secondCompared, KeySet * result, bool checkedIsDominant,
 			   int baseIndicator, Key * informationKey)
 {
-	ksRewind (checkedSet);
-	ksRewind (firstCompared);
-	ksRewind (secondCompared);
-	Key * checkedKey;
-	while ((checkedKey = ksNext (checkedSet)) != NULL)
+	for (elektraCursor it = 0; it < ksGetSize (checkedSet); ++it)
 	{
+		Key * checkedKey = ksAtCursor (checkedSet, it);
 		/**
 		 * Check if a key with the same name exists
 		 * Nothing about values is said yet
@@ -837,15 +834,21 @@ static int numberOfConflictMarkers (const char * text)
 static int handleArrays (KeySet * ourSet, KeySet * theirSet, KeySet * baseSet, KeySet * resultSet, Key * informationKey, int strategy)
 {
 	ELEKTRA_LOG ("cmerge now handles arrays");
-	Key * checkedKey;
 	KeySet * toAppend = NULL;
-	while ((checkedKey = ksNext (baseSet)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (baseSet); ++it)
 	{
+		Key * checkedKey = ksAtCursor (baseSet, it);
+
 		if (elektraArrayValidateName (checkedKey) >= 0)
 		{
 			Key * keyInOur = ksLookup (ourSet, checkedKey, 0);
 			Key * keyInTheir = ksLookup (theirSet, checkedKey, 0);
+			/* getValuesAsArray() calls ksLookup() with  KDP_O_POP which makes as ksRewind()*/
 			char * baseArray = getValuesAsArray (baseSet, checkedKey, informationKey);
+
+			if (baseArray && *baseArray) it = 0;
+
 			if (baseArray == NULL)
 			{
 				ELEKTRA_SET_INTERNAL_ERROR (informationKey, "Could not convert `base` KeySet into char[] for LibGit.");
@@ -978,9 +981,6 @@ KeySet * elektraMerge (KeySet * our, Key * ourRoot, KeySet * their, Key * theirR
 		return NULL;
 	}
 	KeySet * result = ksNew (0, KS_END);
-	ksRewind (ourCropped);
-	ksRewind (theirCropped);
-	ksRewind (baseCropped);
 	bool ourDominant = false;
 	bool theirDominant = false;
 	switch (strategy)
@@ -1005,9 +1005,6 @@ KeySet * elektraMerge (KeySet * our, Key * ourRoot, KeySet * their, Key * theirR
 	ELEKTRA_LOG ("cmerge can NOT use libgit2 to handle arrays");
 #endif
 
-	ksRewind (ourCropped);
-	ksRewind (theirCropped);
-	ksRewind (baseCropped);
 	checkSingleSet (baseCropped, ourCropped, theirCropped, result, false, 0, informationKey); // base is never dominant
 	checkSingleSet (theirCropped, baseCropped, ourCropped, result, theirDominant, 1, informationKey);
 	checkSingleSet (ourCropped, theirCropped, baseCropped, result, ourDominant, 2, informationKey);
