@@ -224,21 +224,41 @@ KeySetPair splitEmptyArrayParents (kdb::KeySet const & arrayParents)
 
 	for (auto arrayParent : arrayParents)
 	{
-		kdb::Key parent = arrayParent.dup ();
-
-		parent.rewindMeta ();
-		size_t metaSize = 0;
-		bool isEmpty = parent.getBinarySize () == 0;
-		while (isEmpty && parent.nextMeta ())
+		if (arrayParent.getBinarySize () != 0 || !arrayParent.hasMeta ("array"))
 		{
-			if (metaSize > 2 || parent.currentMeta ().getName () != "binary" || parent.currentMeta ().getName () != "array")
-			{
-				isEmpty = false;
-			}
-			metaSize++;
+			// has value, or is not actually array parent -> non-empty
+			nonEmptyParents.append (arrayParent);
+			continue;
 		}
-		(isEmpty ? emptyParents : nonEmptyParents).append (arrayParent);
+
+
+		/* TODO: Using ksGetSize() instead of keyNextMeta() to determine the number of metakeys produces
+		 * additional "___dirdata:" entries when using the yajl-plugin with arrays! */
+		// ckdb::KeySet * metaKeys = ckdb::keyMeta (arrayParent.getKey ());
+		// ssize_t metaKeysSizeWithKsGetSize = ckdb::ksGetSize (metaKeys);
+
+		ssize_t metaKeysSize = 0;
+		while (ckdb::keyNextMeta (arrayParent.getKey ()))
+			metaKeysSize++;
+
+		if (arrayParent.hasMeta ("binary") && metaKeysSize > 2)
+		{
+			// has meta:/binary and at least 2 other metakeys (incl. meta:/array) -> non-empty
+			nonEmptyParents.append (arrayParent);
+			continue;
+		}
+
+		if (metaKeysSize > 1)
+		{
+			// no meta:/binary, but at least 2 other metakeys (incl. meta:/array) -> non-empty
+			nonEmptyParents.append (arrayParent);
+			continue;
+		}
+
+		// only one metakey, which must be meta:/array -> empty
+		emptyParents.append (arrayParent);
 	}
+
 #ifdef HAVE_LOGGER
 	ELEKTRA_LOG_DEBUG ("Empty array parents:");
 	logKeySet (emptyParents);
@@ -325,17 +345,27 @@ kdb::KeySet decreaseArrayIndices (kdb::KeySet const & parents, kdb::KeySet const
  */
 KeySetPair splitDirectoriesLeaves (kdb::KeySet const & keys)
 {
+
 	kdb::KeySet leaves;
 	kdb::KeySet directories;
 
-	keys.rewind ();
-	kdb::Key previous;
-	for (previous = keys.next (); keys.next (); previous = keys.current ())
+	kdb::Key previous = keys.at (0);
+	for (elektraCursor it = 1; it < keys.size (); ++it)
 	{
-		(keys.current ().isBelow (previous) ? directories : leaves).append (previous);
+		kdb::Key current = keys.at (it);
+
+
+		if (current.isBelow (previous))
+		{
+			directories.append (previous);
+		}
+		else
+		{
+			leaves.append (previous);
+		}
+		previous = current;
 	}
 	leaves.append (previous);
-
 	return make_pair (directories, leaves);
 }
 
