@@ -4,6 +4,7 @@
  * @brief Header for process plugin
  *
  * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
+ *
  */
 
 #ifndef ELEKTRA_PLUGIN_PROCESS_H
@@ -16,10 +17,7 @@ int elektraProcessOpen (Plugin * handle, Key * errorKey);
 int elektraProcessClose (Plugin * handle, Key * errorKey);
 int elektraProcessGet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraProcessSet (Plugin * handle, KeySet * ks, Key * parentKey);
-int elektraProcessError (Plugin * handle, KeySet * ks, Key * parentKey);
-int elektraProcessCheckConf (Key * errorKey, KeySet * conf);
 
 Plugin * ELEKTRA_PLUGIN_EXPORT;
 
-
 #endif
