@@ -66,12 +66,16 @@ static inline void freeArgv (char ** argv)
 
 static int copyError (Key * dest, Key * src)
 {
-	keyRewindMeta (src);
 	const Key * metaKey = keyGetMeta (src, "error");
 	if (!metaKey) return 0;
 	keySetMeta (dest, keyName (metaKey), keyString (metaKey));
-	while ((metaKey = keyNextMeta (src)) != NULL)
+
+
+	KeySet * metaKeys = keyMeta ((Key *) metaKey);
+
+	for (elektraCursor it = 0; it < ksGetSize (metaKeys); ++it)
 	{
+		metaKey = ksAtCursor (metaKeys, it);
 		if (strncmp (keyName (metaKey), "error/", 6) != 0) break;
 		keySetMeta (dest, keyName (metaKey), keyString (metaKey));
 	}
@@ -279,13 +283,16 @@ int elektraSpecloadSet (Plugin * handle, KeySet * returned, Key * parentKey)
 
 	KeySet * overrides = ksNew (0, KS_END);
 
-	elektraCursor cursor = ksGetCursor (returned);
-	ksRewind (returned);
 	Key * new;
 	Key * old;
-	while ((new = ksNext (returned)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (returned); ++it)
 	{
+		new = ksAtCursor (returned, it);
+
+		/* internal cursor of oldData should not change because of KDB_O_POP argument */
 		old = ksLookup (oldData, new, KDB_O_POP);
+
 		if (old == NULL)
 		{
 			old = ksLookup (spec, new, 0);
@@ -297,7 +304,6 @@ int elektraSpecloadSet (Plugin * handle, KeySet * returned, Key * parentKey)
 		if (changeAllowed < 0)
 		{
 			ELEKTRA_SET_RESOURCE_ERROR (parentKey, "This kind of change is not allowed");
-			ksSetCursor (returned, cursor);
 			ksDel (overrides);
 			ksDel (oldData);
 			ksDel (spec);
@@ -312,11 +318,12 @@ int elektraSpecloadSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	ksDel (spec);
 
 	// check if remaining old keys can be removed
-	while ((old = ksNext (oldData)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (oldData); ++it)
 	{
+		old = ksAtCursor (oldData, it);
 		if (isChangeAllowed (old, NULL) > 0)
 		{
-			ksSetCursor (returned, cursor);
 			ksDel (overrides);
 			ksDel (oldData);
 			return ELEKTRA_PLUGIN_STATUS_ERROR;
@@ -324,8 +331,6 @@ int elektraSpecloadSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	}
 	ksDel (oldData);
 
-	ksSetCursor (returned, cursor);
-
 	int result = elektraInvoke2Args (specload->quickDump, "set", overrides, parentKey);
 	ksDel (overrides);
 	return result;
@@ -443,10 +448,11 @@ bool readConfig (KeySet * conf, char ** directFilePtr, char ** appPtr, char ***
 	argv[0] = elektraStrDup (app);
 
 	size_t index = 1;
-	ksRewind (args);
 	Key * cur;
-	while ((cur = ksNext (args)) != NULL)
+
+	for (elektraCursor it = 0; it < ksGetSize (args); ++it)
 	{
+		cur = ksAtCursor (args, it);
 		argv[index] = elektraStrDup (keyString (cur));
 		++index;
 	}
@@ -678,31 +684,23 @@ int isChangeAllowed (Key * oldKey, Key * newKey)
  */
 int keyCompareMeta (const Key * k1, const Key * k2)
 {
-	const Key * meta1;
-
 	Key * key1 = (Key *) k1;
 	Key * key2 = (Key *) k2;
 
-	keyRewindMeta (key1);
-	keyRewindMeta (key2);
-	while ((meta1 = keyNextMeta (key1)) != 0)
+	KeySet * metaKeys1 = keyMeta (key1);
+	KeySet * metaKeys2 = keyMeta (key2);
+
+	if (ksGetSize (metaKeys1) != ksGetSize (metaKeys2)) return -1;
+
+	for (elektraCursor it = 0; it < ksGetSize (metaKeys1); ++it)
 	{
-		const Key * meta2 = keyNextMeta (key2);
-		if (!meta2)
-		{
-			return -1;
-		}
+		const Key * meta1 = ksAtCursor (metaKeys1, it);
+		const Key * meta2 = ksAtCursor (metaKeys2, it);
 
 		if (strcmp (keyName (meta1), keyName (meta2))) return -1;
 		if (strcmp (keyString (meta1), keyString (meta2))) return -1;
 	}
 
-	if (keyNextMeta (key2))
-	{
-		return -1;
-	}
-
-	// TODO: rewind metadata to previous position
 	return 0;
 }
 
@@ -727,11 +725,14 @@ KeySet * calculateMetaDiff (Key * oldKey, Key * newKey)
 {
 	KeySet * result = ksNew (0, KS_END);
 
-	keyRewindMeta (oldKey);
-	keyRewindMeta (newKey);
+	KeySet * oldMetaKeys = keyMeta (oldKey);
+	KeySet * newMetaKeys = keyMeta (newKey);
 
-	const Key * oldMeta = keyNextMeta (oldKey);
-	const Key * newMeta = keyNextMeta (newKey);
+	const Key * oldMeta = ksAtCursor (oldMetaKeys, 0);
+	const Key * newMeta = ksAtCursor (newMetaKeys, 0);
+
+	elektraCursor itOldMeta = 1;
+	elektraCursor itNewMeta = 1;
 
 	while (oldMeta != NULL && newMeta != NULL)
 	{
@@ -743,32 +744,32 @@ KeySet * calculateMetaDiff (Key * oldKey, Key * newKey)
 		{
 			// oldKey has to "catch up"
 			ksAppendKey (result, keyNew (oldName, KEY_VALUE, "remove", KEY_META, "old", keyString (oldMeta), KEY_END));
-			oldMeta = keyNextMeta (oldKey);
+			oldMeta = ksAtCursor (oldMetaKeys, itOldMeta++);
 		}
 		else if (cmp > 0)
 		{
 			// newKey has to "catch up"
 			ksAppendKey (result, keyNew (newName, KEY_VALUE, "add", KEY_META, "new", keyString (newMeta), KEY_END));
-			newMeta = keyNextMeta (newKey);
+			newMeta = ksAtCursor (newMetaKeys, itNewMeta++);
 		}
 		else
 		{
 			// same name
 			ksAppendKey (result, keyNew (oldName, KEY_VALUE, "edit", KEY_META, "old", keyString (oldMeta), KEY_META, "new",
 						     keyString (newMeta), KEY_END));
-			oldMeta = keyNextMeta (oldKey);
-			newMeta = keyNextMeta (newKey);
+			oldMeta = ksAtCursor (oldMetaKeys, itOldMeta++);
+			newMeta = ksAtCursor (newMetaKeys, itNewMeta++);
 		}
 	}
 
 	// remaining metadata in oldKey was removed
-	while ((oldMeta = keyNextMeta (oldKey)) != NULL)
+	while ((oldMeta = ksAtCursor (oldMetaKeys, itOldMeta++)) != NULL)
 	{
 		ksAppendKey (result, keyNew (keyName (oldMeta), KEY_VALUE, "remove", KEY_META, "old", keyString (oldMeta), KEY_END));
 	}
 
 	// remaining metadata in newKey was added
-	while ((newMeta = keyNextMeta (newKey)) != NULL)
+	while ((newMeta = ksAtCursor (newMetaKeys, itNewMeta++)) != NULL)
 	{
 		ksAppendKey (result, keyNew (keyName (newMeta), KEY_VALUE, "add", KEY_META, "new", keyString (newMeta), KEY_END));
 	}
