@@ -19,14 +19,23 @@ int elektraTracerOpen (Plugin * handle, Key * errorKey)
 	ssize_t nr_keys = 0;
 	KeySet * config = elektraPluginGetConfig (handle);
 
-	if (ksLookupByName (config, "/module", 0))
+	Key * searchKey = keyNew ("/module", KEY_END);
+	elektraCursor it = ksSearch (config, searchKey);
+	keyDel (searchKey);
+
+	if (it >= 0) // key found
 	{
-		if (ksLookupByName (config, "/logmodule", 0))
+		searchKey = keyNew ("/logmodule", KEY_END);
+		it = ksSearch (config, searchKey);
+
+		if (it >= 0)
 		{
 			Key * k;
 			printf ("tracer: openmodule(%p, %s = %s): ", (void *) handle, keyName (errorKey), keyString (errorKey));
-			while ((k = ksNext (config)) != 0)
+
+			for (++it; it < ksGetSize (config); ++it)
 			{
+				k = ksAtCursor (config, it);
 				printf ("%s=%s ", keyName (k), keyString (k));
 				++nr_keys;
 			}
@@ -37,15 +46,16 @@ int elektraTracerOpen (Plugin * handle, Key * errorKey)
 	{
 		Key * k;
 		printf ("tracer: open(%p, %s = %s): ", (void *) handle, keyName (errorKey), keyString (errorKey));
-		while ((k = ksNext (config)) != 0)
+
+		for (it = 0; it < ksGetSize (config); ++it)
 		{
+			k = ksAtCursor (config, it);
 			printf ("%s=%s ", keyName (k), keyString (k));
 			++nr_keys;
 		}
 		printf ("%zd\n", nr_keys);
 	}
 
-
 	return 0;
 }
 
@@ -73,26 +83,28 @@ int elektraTracerGet (Plugin * handle, KeySet * returned, Key * parentKey)
 	ssize_t nr_keys = 0;
 	Key * k = 0;
 
-	if (!strcmp (keyName (parentKey), "system/elektra/modules/tracer"))
+	if (!strcmp (keyName (parentKey), "system:/elektra/modules/tracer"))
 	{
 		KeySet * info =
-			ksNew (50, keyNew ("system/elektra/modules/tracer", KEY_VALUE, "tracer plugin waits for your orders", KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports", KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports/open", KEY_FUNC, elektraTracerOpen, KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports/close", KEY_FUNC, elektraTracerClose, KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports/get", KEY_FUNC, elektraTracerGet, KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports/set", KEY_FUNC, elektraTracerSet, KEY_END),
-			       keyNew ("system/elektra/modules/tracer/exports/error", KEY_FUNC, elektraTracerError, KEY_END),
+			ksNew (50, keyNew ("system:/elektra/modules/tracer", KEY_VALUE, "tracer plugin waits for your orders", KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports", KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports/open", KEY_FUNC, elektraTracerOpen, KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports/close", KEY_FUNC, elektraTracerClose, KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports/get", KEY_FUNC, elektraTracerGet, KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports/set", KEY_FUNC, elektraTracerSet, KEY_END),
+			       keyNew ("system:/elektra/modules/tracer/exports/error", KEY_FUNC, elektraTracerError, KEY_END),
 #include "readme_tracer.c"
-			       keyNew ("system/elektra/modules/tracer/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
+			       keyNew ("system:/elektra/modules/tracer/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END);
 		ksAppend (returned, info);
 		ksDel (info);
 		return 1;
 	}
 
 	printf ("tracer: get(%p, %s, %s): ", (void *) handle, keyName (parentKey), keyString (parentKey));
-	while ((k = ksNext (returned)) != 0)
+
+	for (elektraCursor it = 0; it < ksGetSize (returned); ++it)
 	{
+		k = ksAtCursor (returned, it);
 		printf ("%s ", keyName (k));
 		++nr_keys;
 	}
@@ -107,8 +119,10 @@ int elektraTracerSet (Plugin * handle, KeySet * returned, Key * parentKey)
 	Key * k = 0;
 
 	printf ("tracer: set(%p, %s, %s): ", (void *) handle, keyName (parentKey), keyString (parentKey));
-	while ((k = ksNext (returned)) != 0)
+
+	for (elektraCursor it = 0; it < ksGetSize (returned); ++it)
 	{
+		k = ksAtCursor (returned, it);
 		printf ("%s ", keyName (k));
 		++nr_keys;
 	}
@@ -123,8 +137,10 @@ int elektraTracerError (Plugin * handle, KeySet * returned, Key * parentKey)
 	Key * k = 0;
 
 	printf ("tracer: error(%p, %s, %s): ", (void *) handle, keyName (parentKey), keyString (parentKey));
-	while ((k = ksNext (returned)) != 0)
+
+	for (elektraCursor it = 0; it < ksGetSize (returned); ++it)
 	{
+		k = ksAtCursor (returned, it);
 		printf ("%s ", keyName (k));
 		++nr_keys;
 	}
