@@ -48,15 +48,15 @@ namespace
 kdb::KeySet contractYamlCpp (void)
 {
 	return kdb::KeySet{ 30,
-			    keyNew ("system/elektra/modules/yamlcpp", KEY_VALUE, "yamlcpp plugin waits for your orders", KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/exports", KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/exports/get", KEY_FUNC, elektraYamlcppGet, KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/exports/set", KEY_FUNC, elektraYamlcppSet, KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp", KEY_VALUE, "yamlcpp plugin waits for your orders", KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/exports", KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/exports/get", KEY_FUNC, elektraYamlcppGet, KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/exports/set", KEY_FUNC, elektraYamlcppSet, KEY_END),
 #include ELEKTRA_README
-			    keyNew ("system/elektra/modules/yamlcpp/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/config/needs/binary/meta", KEY_VALUE, "true", KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/config/needs/boolean/restore", KEY_VALUE, "#1", KEY_END),
-			    keyNew ("system/elektra/modules/yamlcpp/config/needs/boolean/restoreas", KEY_VALUE, "none", KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/config/needs/binary/meta", KEY_VALUE, "true", KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/config/needs/boolean/restore", KEY_VALUE, "#1", KEY_END),
+			    keyNew ("system:/elektra/modules/yamlcpp/config/needs/boolean/restoreas", KEY_VALUE, "none", KEY_END),
 			    KS_END };
 }
 }
@@ -74,7 +74,7 @@ int elektraYamlcppGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key *
 	kdb::Key parent = kdb::Key (parentKey);
 	kdb::KeySet keys = kdb::KeySet (returned);
 
-	if (parent.getName () == "system/elektra/modules/yamlcpp")
+	if (parent.getName () == "system:/elektra/modules/yamlcpp")
 	{
 		keys.append (contractYamlCpp ());
 		parent.release ();
