@@ -30,6 +30,15 @@ Backend * b_new (const char * name, const char * value)
 	return backend;
 }
 
+Backend * b_default (void)
+{
+	Backend * backend = elektraCalloc (sizeof (Backend));
+	backend->refcounter = 1;
+	backend->mountpoint = NULL;
+
+	return backend;
+}
+
 static void kdb_del (KDB * kdb)
 {
 	backendClose (kdb->defaultBackend, 0);
@@ -44,32 +53,26 @@ static void test_mount (void)
 	printf ("test mount backend\n");
 
 	KDB * kdb = kdb_new ();
-	mountBackend (kdb, b_new ("user", "user"), 0);
+	mountBackend (kdb, b_new ("user:/", "user"), 0);
 	succeed_if (kdb->trie, "there should be a trie");
 
-	Key * mp = keyNew ("user", KEY_VALUE, "user", KEY_END);
-	Key * sk = keyNew ("user", KEY_VALUE, "user", KEY_END);
+	Key * mp = keyNew ("user:/", KEY_VALUE, "user", KEY_END);
 
 	succeed_if (kdb->split->size == 1, "size of split not correct");
 	compare_key (mp, kdb->split->parents[0]);
 
-	compare_key (mountGetBackend (kdb, sk)->mountpoint, mp);
-	compare_key (mountGetMountpoint (kdb, sk), mp);
+	compare_key (mountGetBackend (kdb, "user:/")->mountpoint, mp);
+	compare_key (mountGetMountpoint (kdb, "user:/"), mp);
 
-	keySetName (sk, "user/below");
-	compare_key (mountGetBackend (kdb, sk)->mountpoint, mp);
-	compare_key (mountGetMountpoint (kdb, sk), mp);
+	compare_key (mountGetBackend (kdb, "user:/below")->mountpoint, mp);
+	compare_key (mountGetMountpoint (kdb, "user:/below"), mp);
 
-	keySetName (sk, "system");
-	kdb->defaultBackend = b_new ("", "default");
-	succeed_if (mountGetBackend (kdb, sk) == kdb->defaultBackend, "did not return default backend");
+	kdb->defaultBackend = b_default ();
+	succeed_if (mountGetBackend (kdb, "system:/") == kdb->defaultBackend, "did not return default backend");
 
-	keySetName (mp, "");
-	keySetString (mp, "default");
-	compare_key (mountGetBackend (kdb, sk)->mountpoint, mp);
-	compare_key (mountGetMountpoint (kdb, sk), mp);
+	succeed_if (mountGetBackend (kdb, "system:/")->mountpoint == NULL, "mountpoint of default backend should be NULL");
+	succeed_if (mountGetMountpoint (kdb, "system:/") == NULL, "mountpoint of default backend should be NULL");
 
-	keyDel (sk);
 	keyDel (mp);
 
 	kdb_del (kdb);
@@ -77,12 +80,12 @@ static void test_mount (void)
 
 KeySet * modules_config (void)
 {
-	return ksNew (5, keyNew ("system/elektra/modules", KEY_END), KS_END);
+	return ksNew (5, keyNew ("system:/elektra/modules", KEY_END), KS_END);
 }
 
 KeySet * minimal_config (void)
 {
-	return ksNew (5, keyNew ("system/elektra/mountpoints", KEY_END), KS_END);
+	return ksNew (5, keyNew ("system:/elektra/mountpoints", KEY_END), KS_END);
 }
 
 
@@ -91,7 +94,7 @@ static void test_minimaltrie (void)
 	printf ("Test minimal mount\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, minimal_config (), modules, errorKey) == 0, "could not open minimal config");
 
@@ -108,8 +111,8 @@ static void test_minimaltrie (void)
 
 KeySet * simple_config (void)
 {
-	return ksNew (5, keyNew ("system/elektra/mountpoints", KEY_END), keyNew ("system/elektra/mountpoints/simple", KEY_END),
-		      keyNew ("system/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "user/tests/simple", KEY_END), KS_END);
+	return ksNew (5, keyNew ("system:/elektra/mountpoints", KEY_END), keyNew ("system:/elektra/mountpoints/simple", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "user:/tests/simple", KEY_END), KS_END);
 }
 
 static void test_simple (void)
@@ -117,9 +120,9 @@ static void test_simple (void)
 	printf ("Test simple mount\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
-	Key * mp = keyNew ("user/tests/simple", KEY_VALUE, "simple", KEY_END);
+	Key * mp = keyNew ("user:/tests/simple", KEY_VALUE, "simple", KEY_END);
 
 	succeed_if (mountOpen (kdb, simple_config (), modules, errorKey) == 0, "could not open trie");
 
@@ -131,26 +134,22 @@ static void test_simple (void)
 
 	exit_if_fail (kdb->trie, "kdb->trie was not build up successfully");
 
-	Key * searchKey = keyNew ("user", KEY_END);
-	Backend * backend = trieLookup (kdb->trie, searchKey);
+	Backend * backend = trieLookup (kdb->trie, "user:/");
 	succeed_if (!backend, "there should be no backend");
 
 
-	keySetName (searchKey, "user/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	Backend * b2 = trieLookup (kdb->trie, searchKey);
+	Backend * b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
@@ -158,16 +157,15 @@ static void test_simple (void)
 	keyDel (errorKey);
 	ksDel (modules);
 	keyDel (mp);
-	keyDel (searchKey);
 	kdb_del (kdb);
 }
 
 KeySet * set_us (void)
 {
-	return ksNew (50, keyNew ("system/elektra/mountpoints", KEY_END), keyNew ("system/elektra/mountpoints/user", KEY_END),
-		      keyNew ("system/elektra/mountpoints/user/mountpoint", KEY_VALUE, "user", KEY_END),
-		      keyNew ("system/elektra/mountpoints/system", KEY_END),
-		      keyNew ("system/elektra/mountpoints/system/mountpoint", KEY_VALUE, "system", KEY_END), KS_END);
+	return ksNew (50, keyNew ("system:/elektra/mountpoints", KEY_END), keyNew ("system:/elektra/mountpoints/user:\\/", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/user:\\//mountpoint", KEY_VALUE, "user:/", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/system:\\/", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/system:\\//mountpoint", KEY_VALUE, "system:/", KEY_END), KS_END);
 }
 
 static void test_us (void)
@@ -180,46 +178,39 @@ static void test_us (void)
 	Key * mp;
 
 	KeySet * config = set_us ();
-	ksAppendKey (config, keyNew ("system/elektra/mountpoints", KEY_END));
+	ksAppendKey (config, keyNew ("system:/elektra/mountpoints", KEY_END));
 	succeed_if (mountOpen (kdb, config, modules, 0) == 0, "could not open mount");
 	succeed_if (mountDefault (kdb, modules, 1, 0) == 0, "could not mount default backend");
 
 	succeed_if (kdb->split->size == 5, "size of split not correct");
-	mp = keyNew ("system", KEY_VALUE, "system", KEY_END);
+	mp = keyNew ("system:/", KEY_VALUE, "system:/", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "user");
-	keySetString (mp, "user");
+	keySetName (mp, "user:/");
+	keySetString (mp, "user:/");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "system/elektra");
+	keySetName (mp, "system:/elektra");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[4]);
 	keyDel (mp);
 
-	Key * key = keyNew ("user/anywhere/backend/simple", KEY_END);
-	Backend * backend = trieLookup (kdb->trie, key);
-
-	keyAddBaseName (key, "somewhere");
-	keyAddBaseName (key, "deep");
-	keyAddBaseName (key, "below");
-	Backend * backend2 = trieLookup (kdb->trie, key);
+	Backend * backend = trieLookup (kdb->trie, "user:/anywhere/backend/simple");
+	Backend * backend2 = trieLookup (kdb->trie, "user:/anywhere/backend/simple/somewhere/deep/below");
 	succeed_if (backend == backend2, "should be same backend");
 	mp = backend->mountpoint;
 	succeed_if (mp, "no mountpoint found");
 	if (mp)
 	{
-		succeed_if_same_string (keyName (mp), "user");
-		succeed_if_same_string (keyString (mp), "user");
+		succeed_if_same_string (keyName (mp), "user:/");
+		succeed_if_same_string (keyString (mp), "user:/");
 	}
 
-	keySetName (key, "system/anywhere/tests/backend/two");
-	Backend * two = trieLookup (kdb->trie, key);
+	Backend * two = trieLookup (kdb->trie, "system:/anywhere/tests/backend/two");
 	succeed_if (two != backend, "should be differnt backend");
 
 	succeed_if ((mp = two->mountpoint) != 0, "no mountpoint found");
-	succeed_if_same_string (keyName (mp), "system");
-	succeed_if_same_string (keyString (mp), "system");
+	succeed_if_same_string (keyName (mp), "system:/");
+	succeed_if_same_string (keyString (mp), "system:/");
 
-	keyDel (key);
 	kdb_del (kdb);
 	elektraModulesClose (modules, 0);
 	ksDel (modules);
@@ -228,8 +219,8 @@ static void test_us (void)
 
 KeySet * cascading_config (void)
 {
-	return ksNew (5, keyNew ("system/elektra/mountpoints", KEY_END), keyNew ("system/elektra/mountpoints/simple", KEY_END),
-		      keyNew ("system/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "/tests/simple", KEY_END), KS_END);
+	return ksNew (5, keyNew ("system:/elektra/mountpoints", KEY_END), keyNew ("system:/elektra/mountpoints/simple", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "/tests/simple", KEY_END), KS_END);
 }
 
 static void test_cascading (void)
@@ -237,7 +228,7 @@ static void test_cascading (void)
 	printf ("Test simple mount with cascading\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, cascading_config (), modules, errorKey) == 0, "could not open trie");
 	succeed_if (mountDefault (kdb, modules, 1, errorKey) == 0, "could not mount default backend");
@@ -248,12 +239,12 @@ static void test_cascading (void)
 	exit_if_fail (kdb->trie, "kdb->trie was not build up successfully");
 
 	succeed_if (kdb->split->size == 7, "size of split not correct");
-	Key * mp = keyNew ("dir/tests/simple", KEY_VALUE, "simple", KEY_END);
+	Key * mp = keyNew ("dir:/tests/simple", KEY_VALUE, "simple", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "user/tests/simple");
+	keySetName (mp, "user:/tests/simple");
 	keySetString (mp, "simple");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "system/tests/simple");
+	keySetName (mp, "system:/tests/simple");
 	keySetString (mp, "simple");
 	compare_key (mp, kdb->split->parents[2]);
 	keyDel (mp);
@@ -261,52 +252,42 @@ static void test_cascading (void)
 	// output_split (kdb->split);
 	// output_trie (kdb->trie);
 
-	Key * searchKey = keyNew ("user", KEY_END);
-	Backend * backend = trieLookup (kdb->trie, searchKey);
+	Backend * backend = trieLookup (kdb->trie, "user:/");
 	succeed_if (!backend, "there should be no backend");
 
-	keySetName (searchKey, "system");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "system:/");
 	succeed_if (!backend, "there should be no backend");
 
 
-	mp = keyNew ("", KEY_VALUE, "simple", KEY_END);
-	elektraKeySetName (mp, "/tests/simple", KEY_CASCADING_NAME);
-
-	keySetName (searchKey, "user/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	mp = keyNew ("/tests/simple", KEY_VALUE, "simple", KEY_END);
+	backend = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	Backend * b2 = trieLookup (kdb->trie, searchKey);
+	Backend * b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "system/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "system:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
-	keySetName (searchKey, "system/tests/simple/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "system/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
@@ -315,17 +296,16 @@ static void test_cascading (void)
 	keyDel (errorKey);
 	ksDel (modules);
 	keyDel (mp);
-	keyDel (searchKey);
 	kdb_del (kdb);
 }
 
 
 KeySet * root_config (void)
 {
-	return ksNew (5, keyNew ("system/elektra/mountpoints", KEY_END), keyNew ("system/elektra/mountpoints/root", KEY_END),
-		      keyNew ("system/elektra/mountpoints/root/mountpoint", KEY_VALUE, "/", KEY_END),
-		      keyNew ("system/elektra/mountpoints/simple", KEY_END),
-		      keyNew ("system/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "user/tests/simple", KEY_END), KS_END);
+	return ksNew (5, keyNew ("system:/elektra/mountpoints", KEY_END), keyNew ("system:/elektra/mountpoints/root", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/root/mountpoint", KEY_VALUE, "/", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/simple", KEY_END),
+		      keyNew ("system:/elektra/mountpoints/simple/mountpoint", KEY_VALUE, "user:/tests/simple", KEY_END), KS_END);
 }
 
 static void test_root (void)
@@ -333,7 +313,7 @@ static void test_root (void)
 	printf ("Test mounting with root\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, root_config (), modules, errorKey) == 0, "could not buildup mount");
 
@@ -343,48 +323,42 @@ static void test_root (void)
 	exit_if_fail (kdb->trie, "trie was not build up successfully");
 
 	succeed_if (kdb->split->size == 5, "size of split not correct");
-	Key * mp = keyNew ("spec", KEY_VALUE, "root", KEY_END);
+	Key * mp = keyNew ("spec:/", KEY_VALUE, "root", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "dir");
+	keySetName (mp, "dir:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "user");
+	keySetName (mp, "user:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[2]);
-	keySetName (mp, "system");
+	keySetName (mp, "system:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[3]);
-	keySetName (mp, "user/tests/simple");
+	keySetName (mp, "user:/tests/simple");
 	keySetString (mp, "simple");
 	compare_key (mp, kdb->split->parents[4]);
 
-	Key * searchKey = keyNew ("", KEY_END);
-	Key * rmp = keyNew ("", KEY_VALUE, "root", KEY_END);
-	elektraKeySetName (rmp, "/", KEY_CASCADING_NAME);
+	Key * rmp = keyNew ("/", KEY_VALUE, "root", KEY_END);
 	Backend * b2 = 0;
 
-	keySetName (searchKey, "user");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/");
 	succeed_if (b2, "there should be a backend");
 	if (b2) compare_key (b2->mountpoint, rmp);
 
 
 	Backend * backend = 0;
-	keySetName (searchKey, "user/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
@@ -392,8 +366,6 @@ static void test_root (void)
 	keyDel (mp);
 	keyDel (rmp);
 
-	keyDel (searchKey);
-
 	kdb_del (kdb);
 	keyDel (errorKey);
 	ksDel (modules);
@@ -404,29 +376,29 @@ static void test_default (void)
 	printf ("Test mounting with default\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, root_config (), modules, errorKey) == 0, "could not buildup mount");
 	succeed_if (mountDefault (kdb, modules, 1, errorKey) == 0, "could not mount default backend");
 
 	succeed_if (kdb->split->size == 6, "size of split not correct");
-	Key * mp = keyNew ("spec", KEY_VALUE, "root", KEY_END);
+	Key * mp = keyNew ("spec:/", KEY_VALUE, "root", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "dir");
+	keySetName (mp, "dir:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "user");
+	keySetName (mp, "user:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[2]);
-	keySetName (mp, "system");
+	keySetName (mp, "system:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[3]);
-	keySetName (mp, "system/elektra");
+	keySetName (mp, "system:/elektra");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[5]);
 
 	// must be last, needed later
-	keySetName (mp, "user/tests/simple");
+	keySetName (mp, "user:/tests/simple");
 	keySetString (mp, "simple");
 	compare_key (mp, kdb->split->parents[4]);
 
@@ -437,56 +409,44 @@ static void test_default (void)
 
 	// output_trie (kdb->trie);
 
-	Key * searchKey = keyNew ("", KEY_END);
-	Key * rmp = keyNew ("", KEY_VALUE, "root", KEY_END);
-	elektraKeySetName (rmp, "/", KEY_CASCADING_NAME);
+	Key * rmp = keyNew ("/", KEY_VALUE, "root", KEY_END);
 	Backend * b2 = 0;
 
-	keySetName (searchKey, "user");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/");
 	succeed_if (b2, "there should be a backend");
 	if (b2) compare_key (b2->mountpoint, rmp);
 
 
 	Backend * backend = 0;
-	keySetName (searchKey, "user/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
-	Key * dmp = keyNew ("", KEY_VALUE, "default", KEY_END);
-	keySetName (searchKey, "system/elektra");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/elektra");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (b2 == kdb->defaultBackend, "should be the default backend");
-	if (b2) compare_key (b2->mountpoint, dmp);
+	if (b2) compare_key (b2->mountpoint, NULL);
 
-	keySetName (searchKey, "system/elektra/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/elektra/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (b2 == kdb->defaultBackend, "should be the default backend");
-	if (b2) compare_key (b2->mountpoint, dmp);
+	if (b2) compare_key (b2->mountpoint, NULL);
 
-	keyDel (dmp);
 	keyDel (mp);
 	keyDel (rmp);
 
-	keyDel (searchKey);
-
 	kdb_del (kdb);
 	keyDel (errorKey);
 	ksDel (modules);
@@ -497,7 +457,7 @@ static void test_modules (void)
 	printf ("Test mounting with modules\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, root_config (), modules, errorKey) == 0, "could not buildup mount");
 	succeed_if (mountDefault (kdb, modules, 1, errorKey) == 0, "could not mount default backend");
@@ -509,27 +469,27 @@ static void test_modules (void)
 	// output_split (kdb->split);
 
 	succeed_if (kdb->split->size == 8, "size of split not correct");
-	Key * mp = keyNew ("spec", KEY_VALUE, "root", KEY_END);
+	Key * mp = keyNew ("spec:/", KEY_VALUE, "root", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "dir");
+	keySetName (mp, "dir:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "user");
+	keySetName (mp, "user:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[2]);
-	keySetName (mp, "system");
+	keySetName (mp, "system:/");
 	keySetString (mp, "root");
 	compare_key (mp, kdb->split->parents[3]);
 	/* we cannot exactly know where resolver+dump is located
 	 *(depending on alphabet)
-	keySetName(mp, "system/elektra/modules/"KDB_DEFAULT_RESOLVER); keySetString (mp, "modules");
+	keySetName(mp, "system:/elektra/modules/"KDB_DEFAULT_RESOLVER); keySetString (mp, "modules");
 	compare_key(mp, kdb->split->parents[4]);
 	*/
-	keySetName (mp, "system/elektra");
+	keySetName (mp, "system:/elektra");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[5]);
 
-	keySetName (mp, "user/tests/simple");
+	keySetName (mp, "user:/tests/simple");
 	keySetString (mp, "simple");
 	compare_key (mp, kdb->split->parents[4]);
 
@@ -537,55 +497,47 @@ static void test_modules (void)
 
 	// output_trie (kdb->trie);
 
-	Key * searchKey = keyNew ("", KEY_END);
-	Key * rmp = keyNew ("", KEY_VALUE, "root", KEY_END);
-	elektraKeySetName (rmp, "/", KEY_CASCADING_NAME);
+	Key * rmp = keyNew ("/", KEY_VALUE, "root", KEY_END);
+	keySetName (rmp, "/");
 	Backend * b2 = 0;
 
-	keySetName (searchKey, "user");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/");
 	succeed_if (b2, "there should be a backend");
 	if (b2) compare_key (b2->mountpoint, rmp);
 
 
 	Backend * backend = 0;
-	keySetName (searchKey, "user/tests/simple");
-	backend = trieLookup (kdb->trie, searchKey);
+	backend = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (backend, "there should be a backend");
 	if (backend) compare_key (backend->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (backend == b2, "should be same backend");
 	if (b2) compare_key (b2->mountpoint, mp);
 
-	Key * dmp = keyNew ("", KEY_VALUE, "default", KEY_END);
-	keySetName (searchKey, "system/elektra");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/elektra");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (b2 == kdb->defaultBackend, "should be the default backend");
-	if (b2) compare_key (b2->mountpoint, dmp);
+	if (b2) compare_key (b2->mountpoint, NULL);
 
-	keySetName (searchKey, "system/elektra/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "system:/elektra/below");
 	succeed_if (b2, "there should be a backend");
 	succeed_if (b2 == kdb->defaultBackend, "should be the default backend");
-	if (b2) compare_key (b2->mountpoint, dmp);
+	if (b2) compare_key (b2->mountpoint, NULL);
 
-	Key * mmp = keyNew ("system/elektra/modules", KEY_VALUE, "modules", KEY_END);
+	Key * mmp = keyNew ("system:/elektra/modules", KEY_VALUE, "modules", KEY_END);
 	keyAddBaseName (mmp, "default");
 
 	/*
-	keySetName(searchKey, "system/elektra/modules/default");
+	keySetName(searchKey, "system:/elektra/modules/default");
 	b2 = trieLookup(kdb->trie, searchKey);
 	succeed_if (b2, "there should be a backend");
 	succeed_if (b2 != kdb->defaultBackend, "should not be the default backend");
@@ -593,12 +545,9 @@ static void test_modules (void)
 	*/
 
 	keyDel (mmp);
-	keyDel (dmp);
 	keyDel (mp);
 	keyDel (rmp);
 
-	keyDel (searchKey);
-
 	kdb_del (kdb);
 	keyDel (errorKey);
 	ksDel (modules);
@@ -609,7 +558,7 @@ static void test_defaultonly (void)
 	printf ("Test mounting with default only\n");
 
 	KDB * kdb = kdb_new ();
-	Key * errorKey = keyNew (0);
+	Key * errorKey = keyNew ("/", KEY_END);
 	KeySet * modules = modules_config ();
 	succeed_if (mountOpen (kdb, minimal_config (), modules, errorKey) == 0, "could not buildup mount");
 	succeed_if (mountDefault (kdb, modules, 1, errorKey) == 0, "could not mount default backend");
@@ -618,15 +567,15 @@ static void test_defaultonly (void)
 	// output_split (kdb->split);
 
 	succeed_if (kdb->split->size == 4, "size of split not correct");
-	Key * mp = keyNew ("spec", KEY_VALUE, "default", KEY_END);
+	Key * mp = keyNew ("spec:/", KEY_VALUE, "default", KEY_END);
 	compare_key (mp, kdb->split->parents[0]);
-	keySetName (mp, "dir");
+	keySetName (mp, "dir:/");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[1]);
-	keySetName (mp, "user");
+	keySetName (mp, "user:/");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[2]);
-	keySetName (mp, "system");
+	keySetName (mp, "system:/");
 	keySetString (mp, "default");
 	compare_key (mp, kdb->split->parents[3]);
 
@@ -635,31 +584,25 @@ static void test_defaultonly (void)
 
 	succeed_if (!kdb->trie, "trie should be empty");
 
-	Key * searchKey = keyNew ("", KEY_END);
 	Backend * b2 = 0;
 
-	keySetName (searchKey, "user");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/");
 	succeed_if (b2 == 0, "should be default backend");
 
 
-	keySetName (searchKey, "user/tests/simple");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple");
 	succeed_if (b2 == 0, "should be default backend");
 
 
-	keySetName (searchKey, "user/tests/simple/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/below");
 	succeed_if (b2 == 0, "should be default backend");
 
 
-	keySetName (searchKey, "user/tests/simple/deep/below");
-	b2 = trieLookup (kdb->trie, searchKey);
+	b2 = trieLookup (kdb->trie, "user:/tests/simple/deep/below");
 	succeed_if (b2 == 0, "should be default backend");
 
 	keyDel (mp);
 
-	keyDel (searchKey);
 
 	kdb_del (kdb);
 	keyDel (errorKey);
