@@ -52,39 +52,39 @@ do_tests() {
 		EOF
 	)
 
-	"$KDB" set "$UKEY/tree/root" ""
-	"$KDB" set "$UKEY/tree/root/text" "root"
-	"$KDB" set "$UKEY/tree/child1" ""
-	"$KDB" set "$UKEY/tree/child1/text" "child1"
-	"$KDB" set "$UKEY/tree/child2" ""
-	"$KDB" set "$UKEY/tree/child2/text" "child2"
-	"$KDB" set "$UKEY/tree/child4" ""
-	"$KDB" set "$UKEY/tree/child4/text" "child4"
-	"$KDB" set "$UKEY/tree/grandchildA" ""
-	"$KDB" set "$UKEY/tree/grandchildA/text" "grandchildA"
-	"$KDB" set "$UKEY/tree/leafA" ""
-	"$KDB" set "$UKEY/tree/leafA/text" "leafA"
-	"$KDB" set "$UKEY/tree/grandchildB" ""
-	"$KDB" set "$UKEY/tree/grandchildB/text" "grandchildB"
-	"$KDB" set "$UKEY/tree/leafB" ""
-	"$KDB" set "$UKEY/tree/leafB/text" "leafB"
+	"$KDB" set -f "$UKEY/tree/root" ""
+	"$KDB" set -f "$UKEY/tree/root/text" "root"
+	"$KDB" set -f "$UKEY/tree/child1" ""
+	"$KDB" set -f "$UKEY/tree/child1/text" "child1"
+	"$KDB" set -f "$UKEY/tree/child2" ""
+	"$KDB" set -f "$UKEY/tree/child2/text" "child2"
+	"$KDB" set -f "$UKEY/tree/child4" ""
+	"$KDB" set -f "$UKEY/tree/child4/text" "child4"
+	"$KDB" set -f "$UKEY/tree/grandchildA" ""
+	"$KDB" set -f "$UKEY/tree/grandchildA/text" "grandchildA"
+	"$KDB" set -f "$UKEY/tree/leafA" ""
+	"$KDB" set -f "$UKEY/tree/leafA/text" "leafA"
+	"$KDB" set -f "$UKEY/tree/grandchildB" ""
+	"$KDB" set -f "$UKEY/tree/grandchildB/text" "grandchildB"
+	"$KDB" set -f "$UKEY/tree/leafB" ""
+	"$KDB" set -f "$UKEY/tree/leafB/text" "leafB"
 
-	"$KDB" meta-set "$UKEY/tree/root/children" "array" "#3"
-	"$KDB" set "$UKEY/tree/root/children/#0" "../../../child1"
-	"$KDB" set "$UKEY/tree/root/children/#1" "../../../child2"
-	"$KDB" set "$UKEY/tree/root/children/#3" "../../../child4"
+	"$KDB" meta-set -f "$UKEY/tree/root/children" "array" "#3"
+	"$KDB" set -f "$UKEY/tree/root/children/#0" "../../../child1"
+	"$KDB" set -f "$UKEY/tree/root/children/#1" "../../../child2"
+	"$KDB" set -f "$UKEY/tree/root/children/#3" "../../../child4"
 
-	"$KDB" meta-set "$UKEY/tree/child4/children" "array" "#1"
-	"$KDB" set "$UKEY/tree/child4/children/#0" "../../../grandchildA"
-	"$KDB" set "$UKEY/tree/child4/children/#1" "../../../grandchildB"
+	"$KDB" meta-set -f "$UKEY/tree/child4/children" "array" "#1"
+	"$KDB" set -f "$UKEY/tree/child4/children/#0" "../../../grandchildA"
+	"$KDB" set -f "$UKEY/tree/child4/children/#1" "../../../grandchildB"
 
-	"$KDB" meta-set "$UKEY/tree/grandchildA/children" "array" "#0"
-	"$KDB" set "$UKEY/tree/grandchildA/children/#0" "../../../leafA"
+	"$KDB" meta-set -f "$UKEY/tree/grandchildA/children" "array" "#0"
+	"$KDB" set -f "$UKEY/tree/grandchildA/children/#0" "../../../leafA"
 
-	"$KDB" meta-set "$UKEY/tree/grandchildB/children" "array" "#0"
-	"$KDB" set "$UKEY/tree/grandchildB/children/#0" "../../../leafB"
+	"$KDB" meta-set -f "$UKEY/tree/grandchildB/children" "array" "#0"
+	"$KDB" set -f "$UKEY/tree/grandchildB/children/#0" "../../../leafB"
 
-	"$KDB" set "$UKEY/root" "../tree/root"
+	"$KDB" set -f "$UKEY/root" "../tree/root"
 
 	./application
 	succeed_if "application could not read test tree"
